==> soapysdr-0.7.2-1-armv6h.pkg.tar.xz: usr/share/doc/soapysdr/html/search/all_e.js <==
var searchData=
[
  ['range_133',['Range',['../classSoapySDR_1_1Range.html',1,'SoapySDR::Range'],['../structSoapySDRArgInfo.html#a5c595fc875042a1fe2122081f2b424ed',1,'SoapySDRArgInfo::range()'],['../classSoapySDR_1_1ArgInfo.html#a6878e84000f63cfd5819b37caee62fe8',1,'SoapySDR::ArgInfo::range()'],['../classSoapySDR_1_1Range.html#add7e85bd9bab9e9741599f4ebf15fafa',1,'SoapySDR::Range::Range(void)'],['../classSoapySDR_1_1Range.html#aabd36297a328d03379e2735c13cdb3c0',1,'SoapySDR::Range::Range(const double minimum, const double maximum, const double step=0.0)']]],
  ['rangelist_134',['RangeList',['../namespaceSoapySDR.html#a75daa1b2fa0c08e898b805ce23d7672e',1,'SoapySDR']]],
  ['readgpio_135',['readGPIO',['../classSoapySDR_1_1Device.html#acaaeec484b98a833020a1afc99f8d4c2',1,'SoapySDR::Device']]],
  ['readgpiodir_136',['readGPIODir',['../classSoapySDR_1_1Device.html#a099fcf6a924abb1d5a648f83a737dc4e',1,'SoapySDR::Device']]],
  ['readi2c_137',['readI2C',['../classSoapySDR_1_1Device.html#aa7785d5af0567d413676252d4990df7f',1,'SoapySDR::Device']]],
  ['readregister_138',['readRegister',['../classSoapySDR_1_1Device.html#abdc7c09c966c3554f38e99bd91c1be60',1,'SoapySDR::Device::readRegister(const std::string &amp;name, const unsigned addr) const'],['../classSoapySDR_1_1Device.html#af1a867298c61f8f8127982eb2084e798',1,'SoapySDR::Device::readRegister(const unsigned addr) const']]],
  ['readregisters_139',['readRegisters',['../classSoapySDR_1_1Device.html#a5533d59843b4f01bcd591abd2be9b857',1,'SoapySDR::Device']]],
  ['readsensor_140',['readSensor',['../classSoapySDR_1_1Device.html#a0b92ce565f9210c1679695abace91fbd',1,'SoapySDR::Device::readSensor(const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#a4cbfbb8ca1abb51820ccb7291e386cd9',1,'SoapySDR::Device::readSensor(const int direction, const size_t channel, const std::string &amp;key) const']]],
  ['readsetting_141',['readSetting',['../classSoapySDR_1_1Device.html#a84fcd2f18846349ab9928c8811c9bbe8',1,'SoapySDR::Device::readSetting(const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#afc3018652b735f9b79479638d8b05f11',1,'SoapySDR::Device::readSetting(const int direction, const size_t channel, const std::string &amp;key) const']]],
  ['readstream_142',['readStream',['../classSoapySDR_1_1Device.html#a872010f1eb64e259981cf31f2e726027',1,'SoapySDR::Device']]],
  ['readstreamstatus_143',['readStreamStatus',['../classSoapySDR_1_1Device.html#a6683daba918938769afb2bfbb40e38af',1,'SoapySDR::Device']]],
  ['readuart_144',['readUART',['../classSoapySDR_1_1Device.html#a7afc3726bbf9b168082bc69cd57ac8fc',1,'SoapySDR::Device']]],
  ['registerloghandler_145',['registerLogHandler',['../namespaceSoapySDR.html#a795feaacf27ca0008193fc362badaf27',1,'SoapySDR']]],
  ['registry_146',['Registry',['../classSoapySDR_1_1Registry.html',1,'SoapySDR::Registry'],['../classSoapySDR_1_1Registry.html#adbe7f91b97f0e0575dc81348480eeaae',1,'SoapySDR::Registry::Registry()']]],
  ['registry_2ehpp_147',['Registry.hpp',['../Registry_8hpp.html',1,'']]],
  ['releasereadbuffer_148',['releaseReadBuffer',['../classSoapySDR_1_1Device.html#ab6ff731c8d6a56e48ac2cf3564172ce3',1,'SoapySDR::Device']]],
  ['releasewritebuffer_149',['releaseWriteBuffer',['../classSoapySDR_1_1Device.html#a2ccccc6e135a399cbc4793897786664a',1,'SoapySDR::Device']]]
];

==> soapysdr-0.7.2-3-armv6h.pkg.tar.xz: usr/share/doc/soapysdr/html/search/all_e.js <==
var searchData=
[
  ['range_133',['Range',['../classSoapySDR_1_1Range.html',1,'SoapySDR::Range'],['../classSoapySDR_1_1Range.html#add7e85bd9bab9e9741599f4ebf15fafa',1,'SoapySDR::Range::Range(void)'],['../classSoapySDR_1_1Range.html#aabd36297a328d03379e2735c13cdb3c0',1,'SoapySDR::Range::Range(const double minimum, const double maximum, const double step=0.0)'],['../structSoapySDRArgInfo.html#a5c595fc875042a1fe2122081f2b424ed',1,'SoapySDRArgInfo::range()'],['../classSoapySDR_1_1ArgInfo.html#a6878e84000f63cfd5819b37caee62fe8',1,'SoapySDR::ArgInfo::range()']]],
  ['rangelist_134',['RangeList',['../namespaceSoapySDR.html#a75daa1b2fa0c08e898b805ce23d7672e',1,'SoapySDR']]],
  ['readgpio_135',['readGPIO',['../classSoapySDR_1_1Device.html#acaaeec484b98a833020a1afc99f8d4c2',1,'SoapySDR::Device']]],
  ['readgpiodir_136',['readGPIODir',['../classSoapySDR_1_1Device.html#a099fcf6a924abb1d5a648f83a737dc4e',1,'SoapySDR::Device']]],
  ['readi2c_137',['readI2C',['../classSoapySDR_1_1Device.html#aa7785d5af0567d413676252d4990df7f',1,'SoapySDR::Device']]],
  ['readregister_138',['readRegister',['../classSoapySDR_1_1Device.html#abdc7c09c966c3554f38e99bd91c1be60',1,'SoapySDR::Device::readRegister(const std::string &amp;name, const unsigned addr) const'],['../classSoapySDR_1_1Device.html#af1a867298c61f8f8127982eb2084e798',1,'SoapySDR::Device::readRegister(const unsigned addr) const']]],
  ['readregisters_139',['readRegisters',['../classSoapySDR_1_1Device.html#a5533d59843b4f01bcd591abd2be9b857',1,'SoapySDR::Device']]],
  ['readsensor_140',['readSensor',['../classSoapySDR_1_1Device.html#a0b92ce565f9210c1679695abace91fbd',1,'SoapySDR::Device::readSensor(const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#a4cbfbb8ca1abb51820ccb7291e386cd9',1,'SoapySDR::Device::readSensor(const int direction, const size_t channel, const std::string &amp;key) const']]],
  ['readsetting_141',['readSetting',['../classSoapySDR_1_1Device.html#a84fcd2f18846349ab9928c8811c9bbe8',1,'SoapySDR::Device::readSetting(const std::string &amp;key) const'],['../classSoapySDR_1_1Device.html#afc3018652b735f9b79479638d8b05f11',1,'SoapySDR::Device::readSetting(const int direction, const size_t channel, const std::string &amp;key) const']]],
  ['readstream_142',['readStream',['../classSoapySDR_1_1Device.html#a872010f1eb64e259981cf31f2e726027',1,'SoapySDR::Device']]],
  ['readstreamstatus_143',['readStreamStatus',['../classSoapySDR_1_1Device.html#a6683daba918938769afb2bfbb40e38af',1,'SoapySDR::Device']]],
  ['readuart_144',['readUART',['../classSoapySDR_1_1Device.html#a7afc3726bbf9b168082bc69cd57ac8fc',1,'SoapySDR::Device']]],
  ['registerloghandler_145',['registerLogHandler',['../namespaceSoapySDR.html#a795feaacf27ca0008193fc362badaf27',1,'SoapySDR']]],
  ['registry_146',['Registry',['../classSoapySDR_1_1Registry.html',1,'SoapySDR::Registry'],['../classSoapySDR_1_1Registry.html#adbe7f91b97f0e0575dc81348480eeaae',1,'SoapySDR::Registry::Registry()']]],
  ['registry_2ehpp_147',['Registry.hpp',['../Registry_8hpp.html',1,'']]],
  ['releasereadbuffer_148',['releaseReadBuffer',['../classSoapySDR_1_1Device.html#ab6ff731c8d6a56e48ac2cf3564172ce3',1,'SoapySDR::Device']]],
  ['releasewritebuffer_149',['releaseWriteBuffer',['../classSoapySDR_1_1Device.html#a2ccccc6e135a399cbc4793897786664a',1,'SoapySDR::Device']]]
];
